@@ -9,7 +9,7 @@ use Mojo::Command;
 use Text::Xslate ();
 use Try::Tiny;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->attr('xslate');
@@ -30,7 +30,7 @@ sub _init {
     if ($app) {
         $cache_dir = $app->home->rel_dir('tmp/compiled_templates');
         push @path, Mojo::Command->new->get_all_data(
-            $app->renderer->default_template_class,
+            $app->renderer->classes->[0],
         );
     }
     else {
@@ -162,16 +162,16 @@ L<http://rt.cpan.org/Public/Dist/Display.html?Name=MojoX-Renderer-Xslate>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/MojoX-Renderer-Xslate>
+L<http://search.cpan.org/dist/MojoX-Renderer-Xslate/>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2010-2012 gray <gray at cpan.org>, all rights reserved.
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 =head1 AUTHOR
 
